@@ -6,18 +6,8 @@ def read_env(filename='.env'):
     environment variables from a .env file located in the project root
     directory.
     """
-    try:
-        with open(filename) as f:
-            content = f.read()
-    except IOError:
-        content = ''
-
-    if content == '':
-        try:
-            with open('../.env') as f:
-                content = f.read()
-        except IOError:
-            content = ''
+    with open(filename) as f:
+        content = f.read()
 
     for line in content.splitlines():
         m1 = re.match(r'\A([A-Za-z_0-9]+)=(.*)\Z', line)
