@@ -21,6 +21,10 @@ def convert_to_utc_datetime(time):
 def convert_to_utc_epoch(time):
     return convert_to_utc_datetime(time).timestamp()
 
+def current_utc_datetime():
+    return datetime.utcnow().replace(tzinfo=timezone.utc)
+
 def current_utc_epoch():
-    return datetime.utcnow().replace(tzinfo=timezone.utc).timestamp()
+    return current_utc_datetime().timestamp()
+
 
